@@ -1,19 +1,26 @@
 package Task::POE::Filter::Compression;
+$Task::POE::Filter::Compression::VERSION = '1.04';
+#ABSTRACT: A Task to install all compression related POE Filters.
 
 use strict;
 use warnings;
-use vars qw($VERSION);
 
-$VERSION = '1.02';
-
-1;
+'Cmprss';
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Task::POE::Filter::Compression - A Task to install all compression related POE Filters.
 
+=head1 VERSION
+
+version 1.04
+
 =head1 SYNOPSIS
 
     perl -MCPANPLUS -e 'install Task::POE::Filter::Compression'
@@ -34,12 +41,15 @@ This L<Task> module installs all compression related L<POE::Filter> modules, nam
 
   POE::Filter::Zlib 1.93
 
-=head1 LICENSE
-
-This is free software, released under the same terms as perl itself.
-
 =head1 AUTHOR
 
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
